@@ -20,6 +20,7 @@ from datetime import datetime
 import gconf
 import gtk
 import math
+import os.path
 import string
 
 GCONF_DIR = "/apps/Maemo/advanced_clock_plugin/clock"
@@ -67,17 +68,24 @@ class Clock():
         self.context.paint()
 
         self.context.set_source_rgb(self.color_r, self.color_g, self.color_b)
+
+        if self.alarm_enabled and self.alarm_indicator_enabled :
+            self.context.save()
+            self.draw_alarm_indicator()
+            self.context.restore()
+
         self.context.save()
         self.draw_clock()
         self.context.restore()
 
-        if self.alarm_enabled and self.alarm_indicator_enabled :
-            self.draw_alarm_indicator()
-
     def draw_alarm_indicator(self):
-        self.context.set_source_rgb(1.0, 0.0, 0.0)
-        self.context.arc(self.drawing_area.get_size_request()[0] - 8, 8, 7, 0, 2 * math.pi)
-        self.context.fill()
+        if self.alarm_indicator_icon is not None :
+            self.context.set_source_surface(self.alarm_indicator_icon, self.drawing_area.get_size_request()[0] - self.alarm_indicator_icon.get_width(), 0)
+            self.context.paint()
+        else:
+            self.context.set_source_rgb(1.0, 0.0, 0.0)
+            self.context.arc(self.drawing_area.get_size_request()[0] - 8, 8, 7, 0, 2 * math.pi)
+            self.context.fill()
 
     def draw_clock(self):
         print "Implement draw_clock."
@@ -143,6 +151,9 @@ class Clock():
         if not self.gconf_client.get(GCONF_DIR + "/custom_format") :
             self.gconf_client.set_string(GCONF_DIR + "/custom_format", "")
 
+        if not self.gconf_client.get(GCONF_DIR + "/alarm_indicator_icon") :
+            self.gconf_client.set_string(GCONF_DIR + "/alarm_indicator_icon", "")
+
     def load_gconf_settings(self):
         self.alarm_indicator_enabled = self.gconf_client.get_bool(GCONF_DIR + "/alarm_indicator_enabled")
         self.fill = self.gconf_client.get_bool(GCONF_DIR + "/fill")
@@ -166,6 +177,13 @@ class Clock():
 
         self.custom_format = self.gconf_client.get_string(GCONF_DIR + "/custom_format")
 
+        self.alarm_indicator_icon = None
+        alarm_indicator_icon_file = self.gconf_client.get_string(GCONF_DIR + "/alarm_indicator_icon")
+        if os.path.isfile(alarm_indicator_icon_file) :
+            self.alarm_indicator_icon = cairo.ImageSurface.create_from_png(alarm_indicator_icon_file)
+        else:
+            print "Image file does not exist: " + alarm_indicator_icon_file
+
 # Currently we do not use the callback (see above).
 #        self.gconf_client.notify_add(GCONF_DIR, self.gconf_cb)
 
@@ -174,7 +192,10 @@ class Clock():
 
     def resize_alarm_enabled(self):
         size = self.drawing_area.get_size_request()
-        self.drawing_area.set_size_request(size[0] + 18, size[1])
+        if self.alarm_indicator_icon is not None :
+            self.drawing_area.set_size_request(size[0] + self.alarm_indicator_icon.get_width(), size[1])
+        else:
+            self.drawing_area.set_size_request(size[0] + 18, size[1])
 
     def request_resize(self):
         self.resize_requested = True
